summaryrefslogtreecommitdiffstats
path: root/test/puppet/tc_suidmanager.rb
diff options
context:
space:
mode:
Diffstat (limited to 'test/puppet/tc_suidmanager.rb')
-rwxr-xr-xtest/puppet/tc_suidmanager.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/puppet/tc_suidmanager.rb b/test/puppet/tc_suidmanager.rb
index 0d51ddacd..ddf6a0efc 100755
--- a/test/puppet/tc_suidmanager.rb
+++ b/test/puppet/tc_suidmanager.rb
@@ -122,8 +122,8 @@ class TestSUIDManager < Test::Unit::TestCase
end
def set_exit_status!
- # We want to make sure $? is set, this is the only way I know how.
- Kernel.system '' if $?.nil?
+ # We want to make sure $CHILD_STATUS is set, this is the only way I know how.
+ Kernel.system '' if $CHILD_STATUS.nil?
end
end